precision highp float;

uniform sampler2D texPaint;
uniform sampler2D texInput;
uniform sampler2D texVel;
uniform vec2 uVelScale;
uniform float uFadeCoeff;
uniform float uBorderMirror;

varying highp vec2 varyTexCoord;

vec2 repeatAndMirrorTex(vec2 t)
{
	t = t.x > 1.0 ? vec2(t.x, 1.0 - t.y) : t;
	t = t.x < 0.0 ? vec2(t.x, 1.0 - t.y) : t;
	return t;
}

float repeatTex(float u)
{
	u = u > 1.0 ? u - 1.0 : u;
	u = u < 0.0 ? u + 1.0 : u;
	return u;
}

void main()
{
	// vec2 offset = (texture2D(texVel, varyTexCoord).rg * 2.0 - vec2(1.0)) * 0.5 * uVelScale;
	highp vec2 offset = texture2D(texVel, varyTexCoord).rg * uVelScale;
	highp vec2 samplePos = varyTexCoord - offset;
	
	//samplePos.x = repeatTex(samplePos.x);
	//samplePos.y = repeatTex(samplePos.y);
	
	vec2 samplePosMirrored = repeatAndMirrorTex(samplePos);
	samplePosMirrored.yx = repeatAndMirrorTex(samplePosMirrored.yx);
	
	samplePos = mix(samplePos, samplePosMirrored, uBorderMirror);
	
	vec4 sample = texture2D(texPaint, samplePos) + texture2D(texInput, samplePos) * 20.0;

	gl_FragColor = sample * uFadeCoeff;
}
